@@ -113,6 +113,7 @@ setMethod (
         else
             type.str <- "table "
         sql <- paste("drop ", type.str, table, cascade.str, sep = "")
+        success  <- NULL   # we add this solely to appease R CMD check
         res <- tryCatch(.db.getQuery(sql, conn.id),
                         error = function(e) { success <<- FALSE })
         exists <- db.existsObject(origin.x, conn.id, is.temp)
@@ -166,7 +167,7 @@ setMethod (
     def = function (x) {
         if (is.null(x$model)) return (list(res=TRUE, conn.id=NULL))
         conn.id <- conn.id(x$model)
-        d1 <- delete(x$model)
+        d1 <- delete(x$model) && delete(x$model.summary)
         list(res=d1, conn.id=conn.id)
     })
 
@@ -178,7 +179,7 @@ setMethod (
     def = function (x) {
         if (is.null(x[[1]]$model)) return (list(res=TRUE, conn.id=NULL))
         conn.id <- conn.id(x[[1]]$model)
-        d1 <- delete(x[[1]]$model)
+        d1 <- delete(x[[1]]$model) && delete(x[[1]]$model.summary)
         list(res=d1, conn.id=conn.id)
     })
 
@@ -190,7 +191,7 @@ setMethod (
     def = function (x) {
         if (is.null(x$model)) return (list(res=TRUE, conn.id=NULL))
         conn.id <- conn.id(x$model)
-        d1 <- delete(x$model)
+        d1 <- delete(x$model) && delete(x$model.summary)
         list(res=d1, conn.id=conn.id)
     })
 
@@ -202,7 +203,7 @@ setMethod (
     def = function (x) {
         if (is.null(x[[1]]$model)) return (list(res=TRUE, conn.id=NULL))
         conn.id <- conn.id(x[[1]]$model)
-        d1 <- delete(x[[1]]$model)
+        d1 <- delete(x[[1]]$model) && delete(x[[1]]$model.summary)
         list(res=d1, conn.id=conn.id)
     })
 
