@@ -1,12 +1,13 @@
 ## The environment that contains all environment variables
 .testing.env <- new.env(parent = getNamespace(.this.pkg.name))
-
+# .testing.env <- new.env(parent = globalenv())
 ## ----------------------------------------------------------------------
 
-.get.param.inputs <- function(param.names = c(".port", ".dbname"),
-                              reset = FALSE)
+.get.param.inputs <- function(param.names = c("pivr.port", "pivr.dbname"),
+                              reset = FALSE, curr_env=.testing.env)
 {
     testing.vars <- ls(.testing.env, all.names = TRUE)
+    print(testing.vars)
     if (reset || any(!param.names %in% testing.vars)) {
         cat("\n")
         for (i in param.names)
@@ -25,6 +26,7 @@ skip_if <- function(cond, test.expr)
     l1 <- sum(sapply(gregexpr("expect_that\\(", expr), function(s) sum(s>0)))
     l2 <- sum(sapply(gregexpr("expect_this\\(", expr), function(s) sum(s>0)))
     l <- l1 + l2
+    
     if (cond) {
         if (.localVars$test.reporter %in% c("summary", "minimal"))
             for (i in seq_len(l)) cat(testthat_colourise(",", fg = "purple"))
@@ -89,8 +91,8 @@ test <- function(tests.path = "tests", man.path = NULL, filter = NULL,
         if (! "testthat" %in% .get.installed.pkgs())
             stop("The package 'testthat' could not be installed!")
     }
-    library(testthat)
 
+    loadNamespace('testthat')
     reporter <- eval(parse(text = "testthat:::find_reporter(reporter)"))
 
     if (!is.null(env.file))
@@ -126,7 +128,7 @@ test <- function(tests.path = "tests", man.path = NULL, filter = NULL,
                  })
     }
 
-    if (reporter$failed) {
+    if (!is.null(reporter$failed)) {
         cleanup.conn()
         stop("Test failures", call. = FALSE)
     }
@@ -177,7 +179,7 @@ has_no_error <- function ()
 ## run doc example
 .run.doc.example <- function(reporter, filter, r_root = NULL)
 {
-    library(tools)
+    loadNamespace('tools')
     if (is.null(r_root))
         x <- tools::Rd_db(.this.pkg.name)
     else
@@ -214,7 +216,6 @@ has_no_error <- function ()
             close(con)
         }
     }
-
     testthat::test_dir(outpath, reporter = reporter,
                        env = .testing.env, filter = filter)
 
